@@ -1,44 +1,3 @@
-meanshift<-function(X, x, h){
-  
-  if(is.null(dim(X))){X<-as.vector(X)}
-  if(is.vector(X)){
-    X<-matrix(X,nrow=length(X))
-  }
-  x <- as.numeric(x)
-  d <- length(x)
-  g <- kernd(X, x, h)
-  
-  ms <- NULL
-  for(j in 1:d){
-    ms[j]<-sum(X[,j]*g)/sum(g)
-  }
-  # Alternative: 
-  # ms<- apply(X*g, 2, sum)/sum(g)
-  # this is faster by itself, but it gets slower as soon as integrated into ms.rep....
-  ms
-}
-
-
-# Mean shift iterative function (until convergence ...)
-ms.rep <- function (X, x, h, thresh= 0.0001, iter=200) {    
-  s  <- 0
-  th <- rep(0,iter)
-  M  <-matrix(0, iter, length(x))
-  x0 <- x
-  Xm<-colMeans(X)
-  
-  for (j in 1: iter){           
-    m     <- meanshift(X, x, h)        
-    M[j,] <- m
-    th[j] <- enorm(m-x)/enorm(Xm-x)          
-    if (th[j]<thresh){
-      s<-j;                 
-      break
-    }
-    x     <- m
-  }
-  return(list("Meanshift.points"=M[1:s,], "Threshold.values"=th[1:s], "iterations"=s, "start"=as.numeric(x0),  "final"=m))
-}
 
 # Mean shift clustering
 
